@@ -20,6 +20,5 @@ function array_contains(arguments) {
   if (typeof value === "object" || value === null) {
     return false;
   }
-  const el = Array.from(data).find((x) => x === value);
-  return typeof el === typeof value;
+  return data.includes(value);
 }
